@@ -6,8 +6,8 @@
  *
  * @package plugins
  * @subpackage useracl
- * @copyright 2003-2004 Alexandros Vellis <avel@noc.uoa.gr>
- * @version $Id: html.php,v 1.9 2005/07/15 14:41:37 avel Exp $
+ * @copyright 2003-2006 Alexandros Vellis <avel@noc.uoa.gr>
+ * @version $Id: html.php,v 1.11 2006-07-25 10:31:26 avel Exp $
  *
  * Functions that output HTML markup, used for the presentation logic of the
  * plugin
@@ -265,6 +265,21 @@ function useracl_print_ldapsearchbutton($formname = 'form_addnew') {
 	}
 }
 
+/**
+ * Link to Directory UserInfo (vcard.php) page, if directory plugin is enabled.
+ * @param string $user Username.
+ * @return string
+ */
+function useracl_user_link($user) {
+	global $plugins, $base_uri;
+	if(in_array('directory', $plugins)) {
+        include_once(SM_PATH . 'plugins/directory/include/exported_functions.php');
+        return directory_user_link($user);
+	} else {
+		return $user;
+	}
+}
+
 /**
  * HTML Output functions follow.
  */
